@@ -28,7 +28,10 @@ class Pg:
         self.table = table
 
     
-
+    async def ncfetchs(self):
+        content = await self.pool.fetch(f"SELECT * FROM {self.table})
+ 
+        return content
 
     async def fetch(self, **opt):
         "テーブルの最初のデータを取得する"
